@@ -66,10 +66,14 @@ doFuture2 <- function(obj, expr, envir, data) {   #nolint
 
   ## Support %globals%, %packages%, %seed%, ...
   opts <- getOption("future.disposable", NULL)
-  for (name in names(opts)) {
-    options[name] <- opts[name]
+  if (length(opts) > 0) {
+    for (name in names(opts)) {
+      options[[name]] <- opts[[name]]
+    }
+    if (!identical(attr(opts, "dispose"), FALSE)) {
+      options(future.disposable = NULL)
+    }
   }
-  options(future.disposable = NULL)
 
   error_handling <- obj$errorHandling
   if (!identical(error_handling, "stop")) {
@@ -80,7 +84,7 @@ doFuture2 <- function(obj, expr, envir, data) {   #nolint
       errors <- "future"
     } else if (is.character(errors)) {
       if (length(errors) != 1L) {
-        stop(sprintf("Element 'errors' of '.options.future' should be of length one': [n = %d] %s", length(errors), paste(sQuote(errors), collapse = ", ")))
+        stop(sprintf("Element 'errors' of '.options.future' should be of length one: [n = %d] %s", length(errors), paste(sQuote(errors), collapse = ", ")))
       }
       if (! errors %in% c("future", "foreach")) {
         stop(sprintf("Unknown value of '.options.future' element 'errors': %s", sQuote(errors)))
@@ -343,7 +347,7 @@ doFuture2 <- function(obj, expr, envir, data) {   #nolint
             !any(duplicated(names(globals))),
             !any(duplicated(packages)))
 
-  ## Have the future backend/framework handle also the required 'doFuture'
+  ## Have the future backend/framework also handle the required 'doFuture'
   ## package.  That way we will get a more informative error message in
   ## case it is missing.
   packages <- unique(c("doFuture", packages))
@@ -399,7 +403,7 @@ doFuture2 <- function(obj, expr, envir, data) {   #nolint
         if (length(reserved) > 0) {
           mdebugf_pop() ## "Finding globals in 'args_list' for chunk #%d ..."
           mdebugf_pop() ## "Chunk #%d of %d ..."
-          stop("Detected globals in 'args_list' using reserved variables names: ",
+          stop("Detected globals in 'args_list' using reserved variable names: ",
                paste(sQuote(reserved), collapse = ", "))
         }
         globals_ii <- unique(c(globals_ii, globals_X))
@@ -565,7 +569,7 @@ doFuture2 <- function(obj, expr, envir, data) {   #nolint
         chunk_sizes, names(chunk_sizes))
     chunk_summary <- paste(chunk_summary, collapse = ", ")
     msg <- sprintf("Unexpected error in doFuture(): After gathering and merging the results 
- %d chunks in to a list, the total number of elements (= %d) does not match the number of in
+ %d chunks into a list, the total number of elements (= %d) does not match the number of input
 elements in 'X' (= %d). There were in total %d chunks and %d elements (%s)", 
         nchunks, length(results2), length(args_list), nchunks, 
         sum(chunk_sizes), chunk_summary)
@@ -587,7 +591,7 @@ elements in 'X' (= %d). There were in total %d chunks and %d elements (%s)",
 
 
   ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  ## 10. Accumlate results
+  ## 10. Accumulate results
   ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   ## Combine results (and identify errors)
   ## NOTE: This is adopted from foreach:::doSEQ()
